# Kitty Maze

## Launch

`pip install kitty-maze && kitty-maze`

## Controls

* `ctrl-C`: quit current screen
* `F11`: fullscreen

## Gameplay

* Use the arrow keys to move the player character.
* Walk into objects to learn more about them.
* Click on objects to interact with them. Not all objects are interactive.
* The right side bar contains an inventory, a map, and a narration area. Click
  on filled inventory slots to use items.
